window.Gleam.initSearch([{"doc":"snowgleam","title":"snowgleam","content":"# Snowgleam ❄️\n\nGleam version of the Twitter&#39;s [snowflake](https://github.com/twitter-archive/snowflake/tree/snowflake-2010) format for unique IDs.\nAlthough it is more inspired by the Discord [implementation](https://discord.com/developers/docs/reference#snowflakes) of the snowflake format.\n\nThey are great for generating unique IDs in a distributed system.\n\n```sh\ngleam add snowgleam\n```\nAnd then use it in your project like this:\n```gleam\nimport gleam/io\nimport gleam/int\nimport snowgleam\n\npub fn main() {\n  let assert Ok(generator) = snowgleam.new_generator() |&gt; snowgleam.start()\n  let id = generator |&gt; snowgleam.generate()\n  io.println(&quot;Generated ID: &quot; &lt;&gt; id |&gt; int.to_string())\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/snowgleam&gt;.\n","url":"index.html"},{"doc":"snowgleam","title":"Generator","content":"pub opaque type Generator\n The Snowflake ID generator.\n This is not meant to be used directly but with the provided builder functions.\n\nSynonyms:\nsnowgleam.Generator\nsnowgleam Generator","url":"snowgleam.html#Generator"},{"doc":"snowgleam","title":"Message","content":"pub opaque type Message\n The messages that the generator actor can receive.\n\nSynonyms:\nsnowgleam.Message\nsnowgleam Message","url":"snowgleam.html#Message"},{"doc":"snowgleam","title":"default_epoch","content":"pub const default_epoch: Int\n The default epoch for the generator. Corresponds to the Unix epoch.\nSynonyms:\nsnowgleam.default_epoch\nsnowgleam default_epoch","url":"snowgleam.html#default_epoch"},{"doc":"snowgleam","title":"generate","content":"pub fn generate(channel: Subject(Message)) -&gt; Int\n Generates a new Snowflake ID.\n\n # Examples\n \n import gleam/snowgleam\n\n let epoch = 1_420_070_400_000\n let worker_id = 12\n\n let assert Ok(generator) =\n   snowgleam.new_generator()\n   |&gt; snowgleam.with_epoch(epoch)\n   |&gt; snowgleam.with_worker_id(worker_id)\n   |&gt; snowgleam.start()\n\n let id = snowgleam.generate(generator)\n \nSynonyms:\nsnowgleam.generate\nsnowgleam generate","url":"snowgleam.html#generate"},{"doc":"snowgleam","title":"new_generator","content":"pub fn new_generator() -&gt; Generator\n Creates a new Snowflake ID generator with default settings.\nSynonyms:\nsnowgleam.new_generator\nsnowgleam new_generator","url":"snowgleam.html#new_generator"},{"doc":"snowgleam","title":"process_id","content":"pub fn process_id(id: Int) -&gt; Int\n Extracts the process ID from a Snowflake ID.\nSynonyms:\nsnowgleam.process_id\nsnowgleam process_id","url":"snowgleam.html#process_id"},{"doc":"snowgleam","title":"start","content":"pub fn start(\n  generator: Generator,\n) -&gt; Result(Subject(Message), String)\n Starts the generator.\nSynonyms:\nsnowgleam.start\nsnowgleam start","url":"snowgleam.html#start"},{"doc":"snowgleam","title":"timestamp","content":"pub fn timestamp(id: Int, epoch: Int) -&gt; Int\n Extracts the timestamp from a Snowflake ID using the provided epoch.\nSynonyms:\nsnowgleam.timestamp\nsnowgleam timestamp","url":"snowgleam.html#timestamp"},{"doc":"snowgleam","title":"with_epoch","content":"pub fn with_epoch(generator: Generator, epoch: Int) -&gt; Generator\n Sets the epoch for the generator.\nSynonyms:\nsnowgleam.with_epoch\nsnowgleam with_epoch","url":"snowgleam.html#with_epoch"},{"doc":"snowgleam","title":"with_process_id","content":"pub fn with_process_id(\n  generator: Generator,\n  process_id: Int,\n) -&gt; Generator\n Sets the process ID for the generator.\nSynonyms:\nsnowgleam.with_process_id\nsnowgleam with_process_id","url":"snowgleam.html#with_process_id"},{"doc":"snowgleam","title":"with_worker_id","content":"pub fn with_worker_id(\n  generator: Generator,\n  worker_id: Int,\n) -&gt; Generator\n Sets the worker ID for the generator.\nSynonyms:\nsnowgleam.with_worker_id\nsnowgleam with_worker_id","url":"snowgleam.html#with_worker_id"},{"doc":"snowgleam","title":"worker_id","content":"pub fn worker_id(id: Int) -&gt; Int\n Extracts the worker ID from a Snowflake ID.\nSynonyms:\nsnowgleam.worker_id\nsnowgleam worker_id","url":"snowgleam.html#worker_id"},{"doc":"snowgleam","title":"snowgleam","content":" A module for generating unique IDs using the Twitter Snowflake algorithm.","url":"snowgleam.html"}]);